# sure_tosca_client
TOSCA Simple qUeRy sErvice (SURE). 

This Python package is automatically generated by the [Swagger Codegen](https://github.com/swagger-api/swagger-codegen) project:

- API version: 1.0.0
- Package version: 1.0.1
- Build package: io.swagger.codegen.languages.PythonClientCodegen

## Requirements.

Python 3.6+

## Publish in pypi
```
python setup.py sdist bdist_wheel
python -m  twine upload dist/*
```
## Installation & Usage
### install from pypi.org
```
pip install sure-tosca-client
```
### pip install

If the python package is hosted on Github, you can install directly from Github

```sh
pip install git+https://github.com//.git
```
(you may need to run `pip` with root permission: `sudo pip install git+https://github.com//.git`)

Then import the package:
```python
import swagger_client 
```

### Setuptools

Install via [Setuptools](http://pypi.python.org/pypi/setuptools).

```sh
python setup.py install --user
```
(or `sudo python setup.py install` to install the package for all users)

Then import the package:
```python
import swagger_client
```

## Getting Started

Please follow the [installation procedure](#installation--usage) and then run the following:

```python
from __future__ import print_function
import time
import swagger_client
from swagger_client.rest import ApiException
from pprint import pprint

# create an instance of the API class
api_instance = swagger_client.DefaultApi(swagger_client.ApiClient(configuration))
id = 'id_example' # str | ID of topolog template uplodaed
node_name = 'node_name_example' # str | node_name

try:
    # 
    api_response = api_instance.get_all_ancestor_properties(id, node_name)
    pprint(api_response)
except ApiException as e:
    print("Exception when calling DefaultApi->get_all_ancestor_properties: %s\n" % e)

```

## Documentation for API Endpoints

All URIs are relative to *https://localhost/tosca-sure/1.0.0*

Class | Method | HTTP request | Description
------------ | ------------- | ------------- | -------------
*DefaultApi* | [**get_all_ancestor_properties**](docs/DefaultApi.md#get_all_ancestor_properties) | **GET** /tosca_template/{id}/topology_template/node_templates/{node_name}/ancestors_properties | 
*DefaultApi* | [**get_all_ancestor_types**](docs/DefaultApi.md#get_all_ancestor_types) | **GET** /tosca_template/{id}/topology_template/node_templates/{node_name}/ancestors_types | 
*DefaultApi* | [**get_ancestors_requirements**](docs/DefaultApi.md#get_ancestors_requirements) | **GET** /tosca_template/{id}/topology_template/node_templates/{node_name}/ancestors_requirements | 
*DefaultApi* | [**get_dsl_definitions**](docs/DefaultApi.md#get_dsl_definitions) | **GET** /tosca_template/{id}/dsl_definitions | 
*DefaultApi* | [**get_imports**](docs/DefaultApi.md#get_imports) | **GET** /tosca_template/{id}/imports | 
*DefaultApi* | [**get_node_outputs**](docs/DefaultApi.md#get_node_outputs) | **GET** /tosca_template/{id}/topology_template/node_templates/{node_name}/outputs | 
*DefaultApi* | [**get_node_properties**](docs/DefaultApi.md#get_node_properties) | **GET** /tosca_template/{id}/topology_template/node_templates/{node_name}/properties | 
*DefaultApi* | [**get_node_requirements**](docs/DefaultApi.md#get_node_requirements) | **GET** /tosca_template/{id}/topology_template/node_templates/{node_name}/requirements | 
*DefaultApi* | [**get_node_templates**](docs/DefaultApi.md#get_node_templates) | **GET** /tosca_template/{id}/topology_template/node_templates | 
*DefaultApi* | [**get_node_type_name**](docs/DefaultApi.md#get_node_type_name) | **GET** /tosca_template/{id}/topology_template/node_templates/{node_name}/type_name | 
*DefaultApi* | [**get_parent_type_name**](docs/DefaultApi.md#get_parent_type_name) | **GET** /tosca_template/{id}/topology_template/node_templates/{node_name}/derived_from | 
*DefaultApi* | [**get_related_nodes**](docs/DefaultApi.md#get_related_nodes) | **GET** /tosca_template/{id}/topology_template/node_templates/{node_name}/related | 
*DefaultApi* | [**get_relationship_templates**](docs/DefaultApi.md#get_relationship_templates) | **GET** /tosca_template/{id}/relationship_templates | 
*DefaultApi* | [**get_topology_template**](docs/DefaultApi.md#get_topology_template) | **GET** /tosca_template/{id}/topology_template | 
*DefaultApi* | [**get_tosca_template**](docs/DefaultApi.md#get_tosca_template) | **GET** /tosca_template/{id} | 
*DefaultApi* | [**get_types**](docs/DefaultApi.md#get_types) | **GET** /tosca_template/{id}/types | 
*DefaultApi* | [**set_node_properties**](docs/DefaultApi.md#set_node_properties) | **PUT** /tosca_template/{id}/topology_template/node_templates/{node_name}/properties | 
*DefaultApi* | [**upload_tosca_template**](docs/DefaultApi.md#upload_tosca_template) | **POST** /tosca_template | upload a tosca template description file


## Documentation For Models

 - [NodeTemplate](docs/NodeTemplate.md)
 - [NodeTemplateMap](docs/NodeTemplateMap.md)
 - [TopologyTemplate](docs/TopologyTemplate.md)
 - [ToscaTemplate](docs/ToscaTemplate.md)


## Documentation For Authorization

 All endpoints do not require authorization.


## Author

S.Koulouzis@uva.nl

